Metrics
=======
.. currentmodule:: sksurv.metrics

.. autosummary::
    :toctree: generated/

    brier_score
    concordance_index_censored
    concordance_index_ipcw
    cumulative_dynamic_auc
    integrated_brier_score
    as_concordance_index_ipcw_scorer
    as_cumulative_dynamic_auc_scorer
    as_integrated_brier_score_scorer
